==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/antistring/translations/antistring_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Enable Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Block message</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Write log to file</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Conditions</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Antistring notifications</translation>
    </message>
</context>
<context>
    <name>Antistring</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation>     DATA AND TIME      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Don&apos;t use</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Add</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Change</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>AntistringNotification</name>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation>Your interlocutor send you love letter</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/antistring/translations/antistring_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Antistring</source>
        <translation>Antistring</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Enable Antistring</source>
        <translation>Enable Antistring</translation>
    </message>
    <message>
        <source>Block message</source>
        <translation>Block message</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation>Admonition</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Write log to file</source>
        <translation>Write log to file</translation>
    </message>
    <message>
        <source>Conditions</source>
        <translation>Conditions</translation>
    </message>
    <message>
        <source>Antistring notifications</source>
        <translation>Antistring notifications</translation>
    </message>
</context>
<context>
    <name>AntistringConfigurationUiHandler</name>
    <message>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <source>Don&apos;t use</source>
        <translation>Don&apos;t use</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Add</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Change</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
</context>
<context>
    <name>AntistringMessageFilter</name>
    <message>
        <source>     DATA AND TIME      ::   ID   ::    MESSAGE
</source>
        <translation type="unfinished">     DATA AND TIME      ::   ID   ::    MESSAGE
</translation>
    </message>
</context>
<context>
    <name>AntistringNotificationService</name>
    <message>
        <source>Antistring</source>
        <translation type="unfinished">Antistring</translation>
    </message>
    <message>
        <source>Your interlocutor send you love letter</source>
        <translation type="unfinished">Your interlocutor send you love letter</translation>
    </message>
</context>
</TS>
